Ramp

Struct Ramp 

pub struct Ramp { /* private fields */ }
When input 0 changes, move smoothly to the new value over the time in seconds given by input 1.

Implementations

Source

impl Ramp

pub fn new(start_value: Sample) -> Self

pub fn process( &mut self, value: &[Sample], time: &[Sample], ramped_value: &mut [Sample], block_size: BlockSize, sample_rate: SampleRate, ) -> GenState

pub fn init(&mut self)

Source

impl Ramp

pub fn upload(self) -> Handle<RampHandle>

Upload the Gen to the currently selected Graph and return a handle