GraphSettings

Struct GraphSettings 

pub struct GraphSettings {
    pub name: String,
    pub num_inputs: usize,
    pub max_node_inputs: usize,
    pub num_outputs: usize,
    pub block_size: usize,
    pub num_nodes: usize,
    pub sample_rate: Sample,
    pub oversampling: Oversampling,
    pub ring_buffer_size: usize,
}
Pass to Graph::new to set the options the Graph is created with in an ergonomic and clear way.

Fields

name: String

The name of the Graph

num_inputs: usize

The number of inputs to the Graph

max_node_inputs: usize

The maximum number of inputs to a Node contained in the Graph

num_outputs: usize

The number of outputs from the Graph

block_size: usize

The block size this Graph uses for processing.

num_nodes: usize

The maximum number of nodes that can be added to the graph.

sample_rate: Sample

The sample rate this Graph uses for processing.

oversampling: Oversampling

The oversampling factor

ring_buffer_size: usize

The number of messages that can be sent through any of the ring buffers. Ring buffers are used pass information back and forth between the audio thread (GraphGen) and the Graph.

Implementations

Source

impl GraphSettings

pub fn num_inputs(self, num_inputs: usize) -> Self

Set the num_inputs to a new value

pub fn num_outputs(self, num_outputs: usize) -> Self

Set the num_outputs to a new value

pub fn oversampling(self, oversampling: Oversampling) -> Self

Set the oversampling to a new value

pub fn block_size(self, block_size: usize) -> Self

Set the oversampling to a new value