KnystOffline

Struct KnystOffline 

pub struct KnystOffline { /* private fields */ }
For running and inspecting the output of Knyst offline i.e. generating buffers of samples without outputing them anywhere. Removes the associated KnystSphere when dropped.

Implementations

Source

impl KnystOffline

pub fn new( sample_rate: usize, block_size: usize, num_inputs: usize, num_outputs: usize, ) -> KnystOffline

Creates an offline Knyst sphere and activates it. You can then use the modal knyst API as usual, buf you have to manually process blocks of audio samples and store them if you want.

pub fn sphere_id(&self) -> SphereId

Returns the SphereId of the offline sphere

pub fn process_block(&mut self)

Process one block of audio, incl controller

pub fn set_input(&mut self, index: usize, input: &[Sample])

Fill one graph input channel for this block

pub fn assert_eq_output_channel( &self, channel: usize, expected_output: &[Sample], )

Assert the output of one output channel

pub fn output_channel(&self, channel: usize) -> Option<&[Sample]>

Returns a channel of audio if that channel exists