pub enum GenState {
Continue,
FreeSelf,
FreeSelfMendConnections,
FreeGraph(usize),
FreeGraphMendConnections(usize),
}Expand description
The Gen should return Continue unless it needs to free itself or the Graph it is in.
No promise is made as to when the node or the Graph will be freed so the Node needs to do the right thing
if run again the next block. E.g. a node returning FreeSelfMendConnections is expected to act as a
connection bridge from its non constant inputs to its outputs as if it weren’t there. Only inputs with a
corresponding output should be passed through, e.g. in[0] -> out[0], in[1] -> out[1], in[2..5] go nowhere.
The FreeGraph and FreeGraphMendConnections values also return the relative sample in the current block after which the graph should return 0 or connect its non constant inputs to its outputs.
Variants
Continue
Continue running
FreeSelf
Free the node containing the Gen
FreeSelfMendConnections
Free the node containing the Gen, bridging its input node(s) to its output node(s).
FreeGraph(usize)
Free the graph containing the node containing the Gen.
FreeGraphMendConnections(usize)
Free the graph containing the node containing the Gen, bridging its input node(s) to its output node(s).