pub struct GraphSettings {
pub name: String,
pub num_inputs: usize,
pub max_node_inputs: usize,
pub num_outputs: usize,
pub block_size: usize,
pub num_nodes: usize,
pub sample_rate: Sample,
pub oversampling: Oversampling,
pub ring_buffer_size: usize,
}Expand description
Pass to Graph::new to set the options the Graph is created with in an ergonomic and clear way.
Fields
name: StringThe name of the Graph
num_inputs: usizeThe number of inputs to the Graph
max_node_inputs: usizeThe maximum number of inputs to a Node contained in the Graph
num_outputs: usizeThe number of outputs from the Graph
block_size: usizeThe block size this Graph uses for processing.
num_nodes: usizeThe maximum number of nodes that can be added to the graph.
sample_rate: SampleThe sample rate this Graph uses for processing.
oversampling: OversamplingThe oversampling factor
ring_buffer_size: usizeThe number of messages that can be sent through any of the ring buffers. Ring buffers are used pass information back and forth between the audio thread (GraphGen) and the Graph.
Implementations
Sourceimpl GraphSettings
impl GraphSettings
Sourcepub fn num_inputs(self, num_inputs: usize) -> Self
pub fn num_inputs(self, num_inputs: usize) -> Self
Set the num_inputs to a new value
Sourcepub fn num_outputs(self, num_outputs: usize) -> Self
pub fn num_outputs(self, num_outputs: usize) -> Self
Set the num_outputs to a new value
Sourcepub fn oversampling(self, oversampling: Oversampling) -> Self
pub fn oversampling(self, oversampling: Oversampling) -> Self
Set the oversampling to a new value
Sourcepub fn block_size(self, block_size: usize) -> Self
pub fn block_size(self, block_size: usize) -> Self
Set the oversampling to a new value