pub struct NodeChanges { /* private fields */ }Expand description
Multiple changes to the input values of a certain node. See Change for
what kinds of changes can be scheduled. All methods return Self so it can be chained:
Example
use knyst::graph::{NodeChanges, NodeId, SimultaneousChanges};
// In reality, use a real NodeAddress that points to a node.
let my_node = NodeId::new(0);
let node_changes = NodeChanges::new(my_node).set("freq", 442.0).set("amp", 0.5).trigger("reset");
// equivalent to:
// let node_changes = my_node.change().set("freq", 442.0).set("amp", 0.5).trigger("reset");
let mut simultaneous_changes = SimultaneousChanges::now();
simultaneous_changes.push(node_changes);Implementations
Sourceimpl NodeChanges
impl NodeChanges
Sourcepub fn set(self, channel: impl Into<NodeChannel>, value: Sample) -> Self
pub fn set(self, channel: impl Into<NodeChannel>, value: Sample) -> Self
Adds a new value to set for a specific channel. Can be chained.
Sourcepub fn trigger(self, channel: impl Into<NodeChannel>) -> Self
pub fn trigger(self, channel: impl Into<NodeChannel>) -> Self
Adds a trigger for a specific channel. Can be chained.
Sourcepub fn time_offset(self, offset: TimeOffset) -> Self
pub fn time_offset(self, offset: TimeOffset) -> Self
Add this time offset to all the Changes in the NodeChanges. If
you want different offsets for different settings to the same node you
can create multiple NodeChanges.
With the Time::Immediately timing variant for the
SimultaneousChanges only positive offsets are allowed.