pub struct KnystOffline { /* private fields */ }Expand description
For running and inspecting the output of Knyst offline i.e. generating buffers of samples without outputing them anywhere. Removes the associated KnystSphere when dropped.
Implementations
Sourceimpl KnystOffline
impl KnystOffline
Sourcepub fn new(
sample_rate: usize,
block_size: usize,
num_inputs: usize,
num_outputs: usize,
) -> KnystOffline
pub fn new( sample_rate: usize, block_size: usize, num_inputs: usize, num_outputs: usize, ) -> KnystOffline
Creates an offline Knyst sphere and activates it. You can then use the modal knyst API as usual, buf you have to manually process blocks of audio samples and store them if you want.
Sourcepub fn process_block(&mut self)
pub fn process_block(&mut self)
Process one block of audio, incl controller
Sourcepub fn set_input(&mut self, index: usize, input: &[Sample])
pub fn set_input(&mut self, index: usize, input: &[Sample])
Fill one graph input channel for this block
Sourcepub fn assert_eq_output_channel(
&self,
channel: usize,
expected_output: &[Sample],
)
pub fn assert_eq_output_channel( &self, channel: usize, expected_output: &[Sample], )
Assert the output of one output channel
Sourcepub fn output_channel(&self, channel: usize) -> Option<&[Sample]>
pub fn output_channel(&self, channel: usize) -> Option<&[Sample]>
Returns a channel of audio if that channel exists